@@ -20,10 +20,12 @@ public:
     QRegExp urlPattern() const;
     bool urlSupported(const QUrl &url) const;
     void checkUrl(const QUrl &url);
-    void getDownloadUrl(const QUrl &url);
+    void getDownloadRequest(const QUrl &url);
     inline bool loginSupported() const { return true; }
     void login(const QString &username, const QString &password);
     inline bool recaptchaRequired() const { return false; }
+    inline int maximumConnections() const { return m_connections; }
+    bool cancelCurrentOperation();
 
 private:
     void startWait(int msecs);
@@ -38,12 +40,16 @@ private slots:
     void onWaitFinished();
     void startDownload();
 
+signals:
+    void currentOperationCancelled();
+
 private:
     QUrl m_url;
     QUrl m_downloadUrl;
     QString m_fileId;
     QTimer *m_waitTimer;
     int m_waitTime;
+    int m_connections;
 };
 
 #endif // SHAREVNN_H
